#####################################################################
# geturl.tcl
# Clif Flynt -- clif@cflynt.com
#
# Extracts a URL from a mozilla/firefox bookmark file
#
#####################################################################
# findUrl -#
# Finds a line in the text string that matches the
# pattern string. Extracts the URL from that line.
#
# Arguments:
# match The pattern to try and match
# text The string to search for a match in.
#
# Results:
# Returns the matched URL, or ""
proc findUrl {match text} {
  set url ""
  set expression [format {"http://(.*?%s.*?)"} $match] 
  regexp -line -nocase $expression $text full url
  return $url
}
##################################################################### 
#
# Check for a command line argument
# 
if {$argc != 1} { 
  puts "geturl.tcl string"
  exit -1; 
}

#
# Set the bookmark file name depending on the current system.
#
switch $tcl_platform(platform) {
  unix {
    switch $tcl_platform(os) {
      Darwin {
        set paths [glob [file join $env(HOME) Library "Application Support" Firefox Profiles *default bookmarks.html]]
        set bookmarkName  [lindex $paths end]
      }
      default {
        set paths [glob [file join $env(HOME) .mozilla firefox *default bookmarks.html]]
        set bookmarkName  [lindex $paths 0]
      }
    }
  }
  windows {
    set paths [glob [file join C:/ "Documents and Settings" $env(USERNAME) \
        "Application Data" Mozilla Firefox Profiles *.default bookmarks.html]]

    set path [lindex [glob $paths] 0] 
    # Strip potential { and } from the name returned by glob. 
    set bookmarkName [string trim $path "{}"] 
  }
  mac -
  macintosh {
    # Mac OS 8, 9 - No Firefox, look for an old Netscape bookmark file.
    # Find the exact path, with possible unprintable characters. 
    set path [file join $env(PREF FOLDER) Netsc* * Bookmarks.html]
    # If there are multiple personalities, return just one file 
    set path [lindex [glob $path] 0]
    # Strip potential { and } from the name returned by glob. 
    set bookmarkName [string trim $path "{}"] 
  }
  default {
   puts "I don’recognize platform: $tcl platform(platform)"
   exit -1; 
  } 
}
#
# Open the bookmark file, and read in the data
#
 set bookmarkFile [open $bookmarkName ]
 set bookmarks [read $bookmarkFile]
 close $bookmarkFile
 
 puts [findUrl $argv $bookmarks]
